@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,47 +28,20 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 
-#ifndef GCC
-#endif
-
 //_________________________________________________________________________________________________________________
 //	includes
 //_________________________________________________________________________________________________________________
 
 #include <bf_svtools/securityoptions.hxx>
-
-#ifndef _UTL_CONFIGMGR_HXX_
 #include <unotools/configmgr.hxx>
-#endif
-
-#ifndef _UTL_CONFIGITEM_HXX_
 #include <unotools/configitem.hxx>
-#endif
-
-#ifndef _TOOLS_DEBUG_HXX
 #include <tools/debug.hxx>
-#endif
-
-#ifndef _COM_SUN_STAR_UNO_ANY_HXX_
 #include <com/sun/star/uno/Any.hxx>
-#endif
-
-#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
 #include <com/sun/star/uno/Sequence.hxx>
-#endif
-
 #include <com/sun/star/beans/PropertyValue.hpp>
-
-#ifndef _URLOBJ_HXX
 #include <tools/urlobj.hxx>
-#endif
-
-#ifndef _WLDCRD_HXX
 #include <tools/wldcrd.hxx>
-#endif
-
 #include <bf_svtools/pathoptions.hxx>
-
 #include <rtl/logfile.hxx>
 #include "itemholder1.hxx"
 
@@ -92,7 +66,7 @@ namespace binfilter
 #define	DEFAULT_SECLEVEL				3
 #define DEFAULT_TRUSTEDAUTHORS			Sequence< SvtSecurityOptions::Certificate >()
 
-// xmlsec05 depricated
+// xmlsec05 deprecated
 #define	DEFAULT_STAROFFICEBASIC			eALWAYS_EXECUTE
 
 #define	CSTR_SECUREURL					"SecureURL"
@@ -125,22 +99,22 @@ namespace binfilter
 #define PROPERTYNAME_TRUSTEDAUTHOR_SERIALNUMBER	OUString(RTL_CONSTASCII_USTRINGPARAM(CSTR_TRUSTEDAUTHOR_SERIALNUMBER))
 #define PROPERTYNAME_TRUSTEDAUTHOR_RAWDATA		OUString(RTL_CONSTASCII_USTRINGPARAM(CSTR_TRUSTEDAUTHOR_RAWDATA))
 
-// xmlsec05 depricated
+// xmlsec05 deprecated
 #define	PROPERTYNAME_STAROFFICEBASIC	OUString(RTL_CONSTASCII_USTRINGPARAM("OfficeBasic"	))
 #define PROPERTYNAME_EXECUTEPLUGINS     OUString(RTL_CONSTASCII_USTRINGPARAM("ExecutePlugins"  ))
 #define PROPERTYNAME_WARNINGENABLED     OUString(RTL_CONSTASCII_USTRINGPARAM("Warning"  ))
 #define PROPERTYNAME_CONFIRMATIONENABLED OUString(RTL_CONSTASCII_USTRINGPARAM("Confirmation"  ))
-// xmlsec05 depricated
+// xmlsec05 deprecated
 
 
 #define	PROPERTYHANDLE_SECUREURL					0
 
-// xmlsec05 depricated
+// xmlsec05 deprecated
 #define	PROPERTYHANDLE_STAROFFICEBASIC	1
 #define PROPERTYHANDLE_EXECUTEPLUGINS   2
 #define PROPERTYHANDLE_WARNINGENABLED   3
 #define PROPERTYHANDLE_CONFIRMATIONENABLED 4
-// xmlsec05 depricated
+// xmlsec05 deprecated
 
 #define PROPERTYHANDLE_DOCWARN_SAVEORSEND			5
 #define PROPERTYHANDLE_DOCWARN_SIGNING				6
@@ -266,7 +240,7 @@ private:
         sal_Bool									m_bRODisableMacros;
 
 
-        // xmlsec05 depricated
+        // xmlsec05 deprecated
         EBasicSecurityMode      m_eBasicMode;
         sal_Bool                m_bExecutePlugins;
         sal_Bool                m_bWarning;
@@ -306,7 +280,7 @@ SvtSecurityOptions_Impl::SvtSecurityOptions_Impl()
     ,m_bROTrustedAuthors	( CFG_READONLY_DEFAULT		)
     ,m_bRODisableMacros		( sal_True					) // currently is not intended to be changed
 
-    // xmlsec05 depricated
+    // xmlsec05 deprecated
     ,   m_eBasicMode        ( DEFAULT_STAROFFICEBASIC )
     ,   m_bExecutePlugins   ( sal_True                )
     ,   m_bWarning          ( sal_True                )
@@ -315,7 +289,7 @@ SvtSecurityOptions_Impl::SvtSecurityOptions_Impl()
     ,   m_bROWarning        ( CFG_READONLY_DEFAULT    )
     ,   m_bROExecutePlugins ( CFG_READONLY_DEFAULT    )
     ,   m_bROBasicMode      ( CFG_READONLY_DEFAULT    )
-    // xmlsec05 depricated
+    // xmlsec05 deprecated
 
 {
     Sequence< OUString >	seqNames	= GetPropertyNames	(			);
@@ -538,7 +512,7 @@ sal_Int32 SvtSecurityOptions_Impl::GetHandle( const OUString& rName )
     else if( rName.compareToAscii( CSTR_MACRO_DISABLE ) == 0 )
         nHandle = PROPERTYHANDLE_MACRO_DISABLE;
 
-    // xmlsec05 depricated
+    // xmlsec05 deprecated
     else if( rName == PROPERTYNAME_STAROFFICEBASIC )
         nHandle = PROPERTYHANDLE_STAROFFICEBASIC;
     else if( rName == PROPERTYNAME_EXECUTEPLUGINS )
@@ -547,7 +521,7 @@ sal_Int32 SvtSecurityOptions_Impl::GetHandle( const OUString& rName )
         nHandle = PROPERTYHANDLE_WARNINGENABLED;
     else if( rName == PROPERTYNAME_CONFIRMATIONENABLED )
         nHandle = PROPERTYHANDLE_CONFIRMATIONENABLED;
-    // xmlsec05 depricated
+    // xmlsec05 deprecated
 
     else
         nHandle = PROPERTYHANDLE_INVALID;
@@ -715,7 +689,7 @@ void SvtSecurityOptions_Impl::Commit()
             break;
 
 
-            // xmlsec05 depricated
+            // xmlsec05 deprecated
             case PROPERTYHANDLE_STAROFFICEBASIC:
             {
                 bDone = !m_bROBasicMode;
@@ -744,7 +718,7 @@ void SvtSecurityOptions_Impl::Commit()
                     lValues[ nRealCount ] <<= m_bConfirmation;
             }
             break;
-            // xmlsec05 depricated
+            // xmlsec05 deprecated
 
 
             default:
@@ -862,3 +836,5 @@ Mutex& SvtSecurityOptions::GetInitMutex()
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
