@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,7 +28,6 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 
-
 #define INCL_DOS
 #include <stdlib.h>
 
@@ -77,7 +77,6 @@ PDDESTRUCT ImpDdeMgr::MakeDDEObject( HWND hwnd, ATOM hItemName,
     PDDESTRUCT	pddes = 0;
     ULONG		usItemLen;
     PULONG		pulSharedObj;
-    //WRITELOG("MakeDDEObject: Start")
 
     PSZ pItemName = 0;
     if( hItemName != NULL )
@@ -169,11 +168,6 @@ HWND ImpDdeMgr::CreateConversationWnd()
         pWndData->nRefCount = 0;
         WinSetWindowULong( hWnd, 0, (ULONG)pWndData );
         WinSubclassWindow( hWnd, ::ConvWndProc );
-#if 0 && defined( OV_DEBUG )
-        String aStr("ConvWnd created:");
-        aStr += (ULONG)hWnd;
-        WRITELOG((char*)aStr.GetStr())
-#endif
     }
     else
         nLastErrInstance = DMLERR_SYS_ERROR;
@@ -195,20 +189,6 @@ void ImpDdeMgr::DestroyConversationWnd( HWND hWnd )
         {
             delete pObj;
             WinDestroyWindow( hWnd );
-#if 0 && defined( OV_DEBUG )
-            String aStr("ConvWnd destroyed:");
-            aStr += (ULONG)hWnd;
-            WRITELOG((char*)aStr.GetStr())
-#endif
-        }
-        else
-        {
-#if 0 && defined( OV_DEBUG )
-            String aStr("ConvWnd not destroyed (Refcount=");
-            aStr += pObj->nRefCount;
-            aStr += ") "; aStr += (ULONG)hWnd;
-            WRITELOG((char*)aStr.GetStr())
-#endif
         }
     }
 #if defined( OV_DEBUG )
@@ -232,11 +212,6 @@ USHORT ImpDdeMgr::GetConversationWndRefCount( HWND hWnd )
 // static
 USHORT ImpDdeMgr::IncConversationWndRefCount( HWND hWnd )
 {
-#if 0 && defined( OV_DEBUG )
-    String aStr("IncConversationWndRefCount ");
-    aStr += (ULONG)hWnd;
-    WRITELOG((char*)aStr.GetStr())
-#endif
     ImpConvWndData* pObj = (ImpConvWndData*)WinQueryWindowULong( hWnd, 0 );
     DBG_ASSERT(pObj,"Dde:ConvWnd has no data");
     if( pObj )
@@ -362,13 +337,6 @@ void ImpDdeMgr::FreeConvHandle( ImpDdeMgrData* pBase, HCONV hConv,
     BOOL bDestroyHWndThis )
 {
     DBG_ASSERT(pBase,"DDE:No data");
-#if 0 && defined( OV_DEBUG )
-    String aStr("FreeConvHandle: Start ");
-    aStr += (ULONG)hConv;
-    aStr += " Destroy: "; aStr += (USHORT)bDestroyHWndThis;
-    WRITELOG((char*)aStr.GetStr());
-    WRITESTATUS("FreeConvHandle: Start");
-#endif
     if( !pBase )
     {
         WRITELOG("FreeConvHandle: FAIL");
@@ -412,8 +380,6 @@ void ImpDdeMgr::FreeConvHandle( ImpDdeMgrData* pBase, HCONV hConv,
         WRITELOG("FreeConvHandle: FAIL");
     }
 #endif
-    //WRITELOG("FreeConvHandle: END");
-    //WRITESTATUS("FreeConvHandle: End");
 }
 
 // static
@@ -514,7 +480,6 @@ void ImpDdeMgr::FreeTransaction( ImpDdeMgrData* pBase, ULONG nTransId )
     DBG_ASSERT(pPtr->hConvOwner!=0,"DDE:TransId has no owner");
     if( pPtr->hConvOwner )
     {
-        //WRITELOG("Freeing transaction");
         DdeFreeStringHandle( pPtr->hszItem );
         memset( pPtr, 0, sizeof(Transaction) );
         DBG_ASSERT(pBase->nCurTransCount,"Dde:Invalid Trans. count");
@@ -568,11 +533,6 @@ HSZ ImpDdeMgr::DdeCreateStringHandle( PSZ pszString, int iCodePage)
         return (HSZ)0;
     // Atom-Table beachtet Gross/Kleinschreibung, DDEML aber nicht
 
-    // OV 12.4.96: Services,Topics,Items case-sensitiv!!!
-    // (Grosskundenanforderung (Reuter-DDE))
-    //strlwr( pszString );
-    //*pszString = (char)toupper(*pszString);
-
     HATOMTBL hAtomTable = WinQuerySystemAtomTable();
     ATOM aAtom = WinAddAtom( hAtomTable, pszString );
     return (HSZ)aAtom;
@@ -714,7 +674,6 @@ BOOL ImpDdeMgr::DisconnectAll()
                 break;
         }
     }
-    //WRITESTATUS("After DisconnectAll()")
     return bRet;
 }
 
@@ -754,7 +713,6 @@ void ImpDdeMgr::FreeTransactions( ImpDdeMgrData* pData, HCONV hConvOwner )
         return;
 
     Transaction* pTrans = GetTransTable( pData );
-//	ImpHCONV* pConvTable = GetConvTable( pData );
     pTrans++;
     for( USHORT nPos=1; nPos < pData->nMaxTransCount; nPos++, pTrans++ )
     {
@@ -794,29 +752,17 @@ void ImpDdeMgr::FreeConversations( ImpDdeMgrData* pData, HWND hWndThis,
 
 BOOL ImpDdeMgr::OwnsConversationHandles()
 {
-    //WRITESTATUS("OwnsConversationHandles()");
-#if 0 && defined( OV_DEBUG )
-    String aStr("OwnsConversationHandles Server:");
-    aStr += (ULONG)hWndServer;
-    WRITELOG((char*)aStr.GetStr())
-#endif
     ImpHCONV* pPtr = GetConvTable( pData );
     for( USHORT nCur = 1; nCur < pData->nMaxConvCount; nCur++, pPtr++ )
     {
         if( pPtr->hWndThis && pPtr->pidOwner == pidThis )
         {
-            //WRITELOG("OwnsConversationHandles: TRUE");
             return TRUE;
         }
     }
-    // WRITELOG("OwnsConversationHandles: FALSE");
     return FALSE;
 }
 
-
-
-// *********************************************************************
-// *********************************************************************
 // *********************************************************************
 
 USHORT DdeInitialize(ULONG* pidInst, PFNCALLBACK pfnCallback,
@@ -1012,3 +958,5 @@ HDDEDATA DdeNameService( ULONG idInst, HSZ hsz1, HSZ hszRes, USHORT afCmd )
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
