@@ -42,16 +42,9 @@
 #include "dflyobj.hxx"		// SdrObject
 #include "frmtool.hxx"	  // ::DrawGraphic
 #include <pormulti.hxx> 	// SwMultiPortion
-
-#ifdef VERT_DISTANCE
-#include <math.h>
-#endif
-
-
+#include <osl/diagnose.h>
 #include <bf_svx/obj3d.hxx>
-
 #include <bf_svx/txtrange.hxx>
-
 #include <bf_svx/lrspitem.hxx>
 #include <bf_svx/ulspitem.hxx>
 #include <txtflcnt.hxx>
@@ -59,9 +52,6 @@
 #include <fmtanchr.hxx>
 #include <fmtflcnt.hxx>
 
-
-
-
 #include <pagefrm.hxx>
 #include <pagedesc.hxx> // SwPageDesc
 #include <tgrditem.hxx>
@@ -146,7 +136,7 @@ namespace binfilter {
 /*N*/             {
 /*N*/                 // assert, if no anchor frame found at 'virtual' drawing object
 /*N*/                 // and return anchor frame of 'master' drawing object.
-/*N*/                 ASSERT( false, "<lcl_TheAnchor(..)> - virtual drawing object with no anchor frame!" );
+/*N*/                 OSL_FAIL( "<lcl_TheAnchor(..)> - virtual drawing object with no anchor frame!" );
 /*N*/                 pRet = pDrawContact->GetAnchor();
 /*N*/             }
 /*N*/         }
@@ -156,7 +146,7 @@ namespace binfilter {
 /*N*/         }
 /*N*/     }
 /*N*/ 
-/*N*/     ASSERT( pRet, "<lcl_TheAnchor(..)> - no anchor frame found!" );
+/*N*/     OSL_ENSURE( pRet, "<lcl_TheAnchor(..)> - no anchor frame found!" );
 /*N*/ 
 /*N*/     return *pRet;
 /*N*/ }
@@ -205,8 +195,8 @@ namespace binfilter {
 
 /*N*/ void SwTxtFormatter::CalcUnclipped( SwTwips& rTop, SwTwips& rBottom )
 /*N*/ {
-/*N*/     ASSERT( ! pFrm->IsVertical() || pFrm->IsSwapped(),
-/*N*/             "SwTxtFormatter::CalcUnclipped with unswapped frame" )
+/*N*/     OSL_ENSURE( ! pFrm->IsVertical() || pFrm->IsSwapped(),
+/*N*/             "SwTxtFormatter::CalcUnclipped with unswapped frame" );
 /*N*/ 
 /*N*/ 	long nFlyAsc, nFlyDesc;
 /*N*/ 	lcl_MaxAscDescent( pCurr, rTop, rBottom, nFlyAsc, nFlyDesc );
@@ -224,8 +214,8 @@ namespace binfilter {
 /*N*/ void SwTxtFormatter::UpdatePos( SwLineLayout *pCurr, Point aStart,
 /*N*/ 	xub_StrLen nStartIdx, sal_Bool bAllWays ) const
 /*N*/ {
-/*N*/     ASSERT( ! pFrm->IsVertical() || pFrm->IsSwapped(),
-/*N*/             "SwTxtFormatter::UpdatePos with unswapped frame" )
+/*N*/     OSL_ENSURE( ! pFrm->IsVertical() || pFrm->IsSwapped(),
+/*N*/             "SwTxtFormatter::UpdatePos with unswapped frame" );
 /*N*/ 
 /*N*/     if( GetInfo().IsTest() )
 /*N*/ 		return;
@@ -247,7 +237,7 @@ namespace binfilter {
 /*N*/ 	KSHORT nAscent = pCurr->GetAscent() + nTmpHeight - pCurr->Height();
 /*N*/ 	sal_uInt8 nFlags = SETBASE_ULSPACE;
 /*N*/ 	if( GetMulti() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*N*/ 	{
+                {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 	else
 /*N*/ 		aTmpInf.Y( aTmpInf.Y() + nAscent );
 /*N*/ 
@@ -263,13 +253,11 @@ namespace binfilter {
 /*N*/ 							   nFlyAsc, nFlyDesc, pPos );
 /*N*/ 			if( pPos->IsGrfNumPortion() )
 /*N*/ 			{
-                    DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 				if( !nFlyAsc && !nFlyDesc )
+                    DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 			}
 /*N*/ 			else
 /*N*/ 			{
 /*N*/                 Point aBase( aTmpInf.GetPos() );
-/*N*/                 if ( GetInfo().GetTxtFrm()->IsVertical() )
-/*N*/                     GetInfo().GetTxtFrm()->SwitchHorizontalToVertical( aBase );
 /*N*/ 
 /*N*/                 ((SwFlyCntPortion*)pPos)->SetBase( *aTmpInf.GetTxtFrm(),
 /*N*/                     aBase, nTmpAscent, nTmpDescent, nFlyAsc,
@@ -277,7 +265,7 @@ namespace binfilter {
 /*N*/ 			}
 /*N*/ 		}
 /*N*/ 		if( pPos->IsMultiPortion() && ((SwMultiPortion*)pPos)->HasFlyInCntnt() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*N*/ 		{
+                {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 		pPos->Move( aTmpInf );
 /*N*/ 		pPos = pPos->GetPortion();
 /*N*/ 	}
@@ -290,8 +278,8 @@ namespace binfilter {
 
 /*N*/ void SwTxtFormatter::AlignFlyInCntBase( long nBaseLine ) const
 /*N*/ {
-/*N*/     ASSERT( ! pFrm->IsVertical() || pFrm->IsSwapped(),
-/*N*/             "SwTxtFormatter::AlignFlyInCntBase with unswapped frame" )
+/*N*/     OSL_ENSURE( ! pFrm->IsVertical() || pFrm->IsSwapped(),
+/*N*/             "SwTxtFormatter::AlignFlyInCntBase with unswapped frame" );
 /*N*/ 
 /*N*/ 	if( GetInfo().IsTest() )
 /*N*/ 		return;
@@ -300,7 +288,7 @@ namespace binfilter {
 /*N*/ 	sal_uInt8 nFlags = SETBASE_NOFLAG;
 /*N*/ 	if( GetMulti() && GetMulti()->HasRotation() )
 /*N*/ 	{
-            DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 		nFlags |= SETBASE_ROTATE;
+            DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 /*N*/ 
 /*N*/ 	long nTmpAscent, nTmpDescent, nFlyAsc, nFlyDesc;
@@ -317,11 +305,7 @@ namespace binfilter {
 /*N*/ 			else
 /*N*/ 			{
 /*N*/                 Point aBase;
-/*N*/                 if ( GetInfo().GetTxtFrm()->IsVertical() )
-/*N*/                 {
-                        DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/                     nBaseLine = GetInfo().GetTxtFrm()->SwitchHorizontalToVertical( nBaseLine );
-/*N*/                 }
-/*N*/                 else
+/*N*/                 if (!GetInfo().GetTxtFrm()->IsVertical())
 /*N*/                     aBase = Point( ((SwFlyCntPortion*)pPos)->GetRefPoint().X(), nBaseLine );
 /*N*/ 
 /*N*/                 ((SwFlyCntPortion*)pPos)->SetBase( *GetInfo().GetTxtFrm(), aBase, nTmpAscent, nTmpDescent,
@@ -343,7 +327,7 @@ namespace binfilter {
 
 /*N*/ sal_Bool SwTxtFormatter::ChkFlyUnderflow( SwTxtFormatInfo &rInf ) const
 /*N*/ {
-/*N*/     ASSERT( rInf.GetTxtFly()->IsOn(), "SwTxtFormatter::ChkFlyUnderflow: why?" );
+/*N*/     OSL_ENSURE( rInf.GetTxtFly()->IsOn(), "SwTxtFormatter::ChkFlyUnderflow: why?" );
 /*N*/ 	if( GetCurr() )
 /*N*/ 	{
 /*N*/ 		// Erst pruefen wir, ob ueberhaupt ein Fly mit der Zeile ueberlappt.
@@ -352,11 +336,8 @@ namespace binfilter {
 /*N*/ 		SwRect aLine( GetLeftMargin(), Y(), rInf.RealWidth(), nHeight );
 /*N*/ 
 /*N*/         SwRect aLineVert( aLine );
-/*N*/         if ( pFrm->IsVertical() )
-/*?*/             pFrm->SwitchHorizontalToVertical( aLineVert );
 /*N*/         SwRect aInter( rInf.GetTxtFly()->GetFrm( aLineVert ) );
 /*N*/         if ( pFrm->IsVertical() )
-                //STRIP001 /*?*/             pFrm->SwitchVerticalToHorizontal( aInter );
 /*N*/ 
 /*N*/ 		if( !aInter.HasArea() )
 /*N*/ 			return sal_False;
@@ -372,11 +353,9 @@ namespace binfilter {
 /*N*/             aLine.Width( pPos->Width() );
 /*N*/ 
 /*N*/             aLineVert = aLine;
-/*N*/             if ( pFrm->IsVertical() )
-/*?*/                 pFrm->SwitchHorizontalToVertical( aLineVert );
 /*N*/             aInter = rInf.GetTxtFly()->GetFrm( aLineVert );
 /*N*/             if ( pFrm->IsVertical() )
-                    {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/                 pFrm->SwitchVerticalToHorizontal( aInter );
+                    {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 
 /*N*/             // new flys from below?
 /*N*/ 			if( !pPos->IsFlyPortion() )
@@ -485,17 +464,15 @@ namespace binfilter {
 /*N*/ 
 /*N*/     SwRect aLineVert( aLine );
 /*N*/     if ( pFrm->IsRightToLeft() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/         pFrm->SwitchLTRtoRTL( aLineVert );
+                {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 
-/*N*/     if ( pFrm->IsVertical() )
-/*N*/         pFrm->SwitchHorizontalToVertical( aLineVert );
 /*N*/     SwRect aInter( pTxtFly->GetFrm( aLineVert ) );
 /*N*/ 
 /*N*/     if ( pFrm->IsRightToLeft() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/         pFrm->SwitchRTLtoLTR( aInter );
+                {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 
 /*N*/     if ( pFrm->IsVertical() )
-            {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/         pFrm->SwitchVerticalToHorizontal( aInter );
+            {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 
 /*N*/     if( aInter.IsOver( aLine ) )
 /*N*/ 	{
@@ -565,7 +542,7 @@ namespace binfilter {
 /*N*/             SWRECTFN( pFrm )
 /*N*/             long nNextTop = pTxtFly->GetNextTop();
 /*N*/             if ( bVert )
-                    {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/                 nNextTop = pFrm->SwitchVerticalToHorizontal( nNextTop );
+                    {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/             if( nNextTop > aInter.Bottom() )
 /*N*/ 			{
 /*N*/                 SwTwips nH = nNextTop - aInter.Top();
@@ -618,7 +595,6 @@ namespace binfilter {
 /*?*/             if ( bVert )
 /*?*/             {
 /*?*/                 Point aPoint( nStartX, 0 );
-/*?*/                 pFrm->SwitchHorizontalToVertical( aPoint );
 /*?*/                 nStartX = aPoint.Y();
 /*?*/             }
 /*?*/ 
@@ -684,12 +660,10 @@ namespace binfilter {
 /*N*/ 	sal_uInt8 nMode = IsQuick() ? SETBASE_QUICK : 0;
 /*N*/ 	if( GetMulti() && GetMulti()->HasRotation() )
 /*N*/ 	{
-            DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 		nMode |= SETBASE_ROTATE;
+            DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 /*N*/ 
 /*N*/     Point aTmpBase( aBase );
-/*N*/     if ( GetInfo().GetTxtFrm()->IsVertical() )
-/*?*/         GetInfo().GetTxtFrm()->SwitchHorizontalToVertical( aTmpBase );
 /*N*/ 
 /*N*/ 	if( pFly )
 /*N*/ 	{
@@ -707,8 +681,6 @@ namespace binfilter {
 /*N*/ 			nMode |= SETBASE_ULSPACE;
 /*N*/ 			if( !rInf.IsTest() )
 /*N*/                 aTmpBase = aBase;
-/*N*/                 if ( GetInfo().GetTxtFrm()->IsVertical() )
-/*?*/                     GetInfo().GetTxtFrm()->SwitchHorizontalToVertical( aTmpBase );
 /*N*/ 
 /*N*/                 pRet->SetBase( *rInf.GetTxtFrm(), aTmpBase, nTmpAscent,
 /*N*/                                nTmpDescent, nFlyAsc, nFlyDesc, nMode );
@@ -812,7 +784,7 @@ namespace binfilter {
 /*N*/ {
 /*N*/     SWAP_IF_SWAPPED( pCurrFrm )
 /*N*/ 
-/*N*/ 	ASSERT( bOn, "IsAnyFrm: Why?" );
+/*N*/ 	OSL_ENSURE( bOn, "IsAnyFrm: Why?" );
 /*N*/ 	SwRect aRect( pCurrFrm->Frm().Pos() + pCurrFrm->Prt().Pos(),
 /*N*/ 		pCurrFrm->Prt().SSize() );
 /*N*/ 
@@ -833,7 +805,7 @@ namespace binfilter {
 
 /*N*/ sal_Bool SwTxtFly::IsAnyObj( const SwRect &rRect ) const
 /*N*/ {
-/*N*/ 	ASSERT ( bOn, "SwTxtFly::IsAnyObj: Who's knocking?" );
+/*N*/ 	OSL_ENSURE( bOn, "SwTxtFly::IsAnyObj: Who's knocking?" );
 /*N*/ 
 /*N*/ 	SwRect aRect( rRect );
 /*N*/ 	if ( aRect.IsEmpty() )
@@ -998,7 +970,7 @@ namespace binfilter {
 /*M*/ 		{
 /*M*/ 			const SwFmtAnchor& rNewA =
 /*M*/ 				((SwContact*)GetUserCall(pNew))->GetFmt()->GetAnchor();
-/*M*/ 			ASSERT( FLY_IN_CNTNT != rNewA.GetAnchorId(), "Don't call GetTop with a FlyInCntFrm" );
+/*M*/ 			OSL_ENSURE( FLY_IN_CNTNT != rNewA.GetAnchorId(), "Don't call GetTop with a FlyInCntFrm" );
 /*M*/ 			if( FLY_PAGE == rNewA.GetAnchorId() )
 /*M*/ 				return sal_True;  // Seitengebundenen wird immer ausgewichen.
 /*M*/ 
@@ -1051,8 +1023,8 @@ namespace binfilter {
 
 /*N*/ SwFlyList *SwTxtFly::InitFlyList()
 /*N*/ {
-/*N*/ 	ASSERT( pCurrFrm, "InitFlyList: No Frame, no FlyList" );
-/*N*/     ASSERT( !pFlyList, "InitFlyList: FlyList already initialized" );
+/*N*/ 	OSL_ENSURE( pCurrFrm, "InitFlyList: No Frame, no FlyList" );
+/*N*/     OSL_ENSURE( !pFlyList, "InitFlyList: FlyList already initialized" );
 /*N*/ 
 /*N*/     SWAP_IF_SWAPPED( pCurrFrm )
 /*N*/ 
@@ -1070,7 +1042,7 @@ namespace binfilter {
 /*N*/         SWRECTFN( pCurrFrm )
 /*N*/         const long nRight = (aRect.*fnRect->fnGetRight)() - 1;
 /*N*/         const long nLeft = (aRect.*fnRect->fnGetLeft)() + 1;
-/*N*/ 		const sal_Bool bFooter = pCurrFrm->IsInFtn();
+/*N*/ 		pCurrFrm->IsInFtn();
 /*N*/       const sal_Bool bR2L = pCurrFrm->IsRightToLeft();
 /*N*/ 
 /*N*/ 		for( MSHORT i = 0; i < nCount; i++ )
@@ -1222,7 +1194,7 @@ namespace binfilter {
 
 /*?*/ void SwContourCache::ClrObject( MSHORT nPos )
 /*?*/ {
-/*?*/ 	ASSERT( pTextRanger[ nPos ], "ClrObject: Allready cleared. Good Bye!" );
+/*?*/ 	OSL_ENSURE( pTextRanger[ nPos ], "ClrObject: Allready cleared. Good Bye!" );
 /*?*/ 	nPntCnt -= pTextRanger[ nPos ]->GetPointCount();
 /*?*/ 	delete pTextRanger[ nPos ];
 /*?*/ 	--nObjCnt;
@@ -1320,7 +1292,7 @@ namespace binfilter {
 /*N*/ 			// Vorsicht #37347: Das GetContour() fuehrt zum Laden der Grafik,
 /*N*/ 			// diese aendert dadurch ggf. ihre Groesse, ruft deshalb ein
 /*N*/ 			// ClrObject() auf.
-/*?*/ 			DBG_BF_ASSERT(0, "STRIP"); //STRIP001 PolyPolygon aPoly;
+/*?*/ 			DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 		else
 /*N*/ 		{
@@ -1532,8 +1504,8 @@ namespace binfilter {
 /*N*/ 								  const SwRect &rLine ) const
 /*N*/ {
 /*N*/ 	// Normalerweise ist der rechte Rand der rechte Rand der Printarea.
-/*N*/     ASSERT( ! pCurrFrm->IsVertical() || ! pCurrFrm->IsSwapped(),
-/*N*/             "SwTxtFly::CalcRightMargin with swapped frame" )
+/*N*/     OSL_ENSURE( ! pCurrFrm->IsVertical() || ! pCurrFrm->IsSwapped(),
+/*N*/             "SwTxtFly::CalcRightMargin with swapped frame" );
 /*N*/     SWRECTFN( pCurrFrm )
 /*N*/     SwTwips nRight = (pCurrFrm->Frm().*fnRect->fnGetLeft)() +
 /*N*/                      (pCurrFrm->Prt().*fnRect->fnGetRight)() + 1;
@@ -1629,8 +1601,8 @@ namespace binfilter {
 /*N*/ void SwTxtFly::CalcLeftMargin( SwRect &rFly, MSHORT nFlyPos,
 /*N*/ 								  const SwRect &rLine ) const
 /*N*/ {
-/*N*/     ASSERT( ! pCurrFrm->IsVertical() || ! pCurrFrm->IsSwapped(),
-/*N*/             "SwTxtFly::CalcLeftMargin with swapped frame" )
+/*N*/     OSL_ENSURE( ! pCurrFrm->IsVertical() || ! pCurrFrm->IsSwapped(),
+/*N*/             "SwTxtFly::CalcLeftMargin with swapped frame" );
 /*N*/     SWRECTFN( pCurrFrm )
 /*N*/     SwTwips nLeft = (pCurrFrm->Frm().*fnRect->fnGetLeft)() +
 /*N*/                     (pCurrFrm->Prt().*fnRect->fnGetLeft)();
@@ -1886,7 +1858,7 @@ namespace binfilter {
 /*N*/ 
 /*N*/     SWAP_IF_SWAPPED( pCurrFrm )
 /*N*/ 
-/*N*/ 	ASSERT( bOn, "IsAnyFrm: Why?" );
+/*N*/ 	OSL_ENSURE( bOn, "IsAnyFrm: Why?" );
 /*N*/ 
 /*N*/     const sal_Bool bRet = ForEach( rLine, NULL, sal_False );
 /*N*/     UNDO_SWAP( pCurrFrm )
