@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,38 +31,23 @@
 #pragma hdrstop
 #endif
 
-#ifndef _HINTIDS_HXX
 #include <hintids.hxx>
-#endif
 
 
-#ifndef _COM_SUN_STAR_I18N_CHARTYPE_HDL
 #include <com/sun/star/i18n/CharType.hdl>
-#endif
-#ifndef _COM_SUN_STAR_I18N_WORDTYPE_HDL
 #include <com/sun/star/i18n/WordType.hdl>
-#endif
 
-#ifndef _PRINT_HXX //autogen
 #include <vcl/print.hxx>
-#endif
 
-#ifndef _FNTCACHE_HXX
 #include <fntcache.hxx>
-#endif
-#ifndef _SWFONT_HXX
 #include <swfont.hxx>
-#endif
-#ifndef _BREAKIT_HXX
 #include <breakit.hxx>
-#endif
 namespace binfilter {
 
 using namespace ::com::sun::star::i18n;
 
 
-#define KAPITAELCHENPROP 66
-
+#define KAPITAELCHENPROP 80
 /*************************************************************************
  *						class SwCapitalInfo
  *
@@ -100,8 +86,7 @@ xub_StrLen lcl_CalcCaseMap( const SwFont& rFnt,
 {
     int j = 0;
     const xub_StrLen nEnd = nOfst + nLen;
-    ASSERT( nEnd <= rOrigString.Len(), "lcl_CalcCaseMap: Wrong parameters" )
-
+    OSL_ENSURE( nEnd <= rOrigString.Len(), "lcl_CalcCaseMap: Wrong parameters" );
     // special case for title case:
     const bool bTitle = SVX_CASEMAP_TITEL == rFnt.GetCaseMap() &&
                         pBreakIt->xBreak.is();
@@ -160,7 +145,7 @@ public:
     const Size &GetSize() const { return aTxtSize; }
 };
 
-/*N*/ void SwDoGetCapitalSize::Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont )
+/*N*/ void SwDoGetCapitalSize::Init( SwFntObj* /*pUpperFont*/, SwFntObj* /*pLowerFont*/ )
 /*N*/ {
 /*N*/ 	aTxtSize.Height() = 0;
 /*N*/ 	aTxtSize.Width() = 0;
@@ -319,7 +304,7 @@ public:
 
 /*N*/ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
 /*N*/ {
-/*N*/ 	ASSERT( pLastFont, "SwFont::DoOnCapitals: No LastFont?!" );
+/*N*/ 	OSL_ENSURE( pLastFont, "SwFont::DoOnCapitals: No LastFont?!" );
 /*N*/ 
 /*N*/ 	Size aPartSize;
 /*N*/ 	long nKana = 0;
@@ -456,7 +441,7 @@ public:
 /*N*/ 			   pBreakIt->GetLocale( eLng ), CharType::LOWERCASE_LETTER);
 /*N*/ 		if( nPos == STRING_LEN || nPos > nMaxPos )
 /*N*/ 			nPos = nMaxPos;
-/*N*/ 		ASSERT( nPos, "nextCharBlock not implemented?" );
+/*N*/ 		OSL_ENSURE( nPos, "nextCharBlock not implemented?" );
 /*N*/ #ifdef DBG_UTIL
 /*N*/ 		if( !nPos )
 /*N*/ 			nPos = nMaxPos;
@@ -477,7 +462,7 @@ public:
 /*?*/ 						++nTmp;
 /*?*/ 					if( nOldPos < nTmp )
 /*?*/ 					{
-                            DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 						pLastFont = pSpaceFont;
+                            DBG_BF_ASSERT(0, "STRIP");
 /*?*/ 					}
 /*?*/ 					while( nTmp < nPos && CH_BLANK != rOldText.GetChar( nTmp ) )
 /*?*/ 						++nTmp;
@@ -525,7 +510,7 @@ public:
 /*N*/ 			   pBreakIt->GetLocale( eLng ), CharType::LOWERCASE_LETTER);
 /*N*/ 		if( nPos == STRING_LEN || nPos > nMaxPos )
 /*N*/ 			nPos = nMaxPos;
-/*N*/ 		ASSERT( nPos, "endOfCharBlock not implemented?" );
+/*N*/ 		OSL_ENSURE( nPos, "endOfCharBlock not implemented?" );
 /*N*/ #ifdef DBG_UTIL
 /*N*/ 		if( !nPos )
 /*N*/ 			nPos = nMaxPos;
@@ -540,7 +525,7 @@ public:
 /*N*/ 	{
 /*N*/ 		if( rDo.GetInf().GetDrawSpace() )
 /*N*/ 		{
-                DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 			pLastFont = pSpaceFont;
+                DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 		if ( bWordWise )
 /*?*/ 			delete pSpaceFontAccess;
@@ -560,3 +545,5 @@ public:
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
